@@ -17,6 +17,7 @@
 
 #ifndef CMD_LINE
 #include <stdlib.h>
+#include <string.h>
 #include <math.h>
 #include <gtk/gtk.h>
 #include <glib.h>
@@ -27,6 +28,7 @@
 #include "program.h"
 #include "select.h"
 #include "statistic.h"
+#include "pstatistic.h"
 #endif
 
 #include "options.h"
